@@ -7,7 +7,7 @@ def mongo_credentials(environment):
     """
     credentials = {
         "uri": os.getenv("MONGO_URI_CONN") or "mongodb://localhost:27017/test",
-        "ssl": os.getenv("MONGO_SSL") or False
+        "ssl": eval(os.getenv("MONGO_SSL")) or False
     }
 
     if not credentials["uri"]:
