@@ -6,28 +6,26 @@ import tensorflow_datasets as tfds
 import pickle
 import numpy as np
 
-import utils.utils as utils
+from utils import utils
 from nkia.ml.cnn_nlp_model import CNN
 import pkg_resources
 
 class classifyProducts(object):
 
     def __init__(self):
-        self.utils = utils
-        self.load_model_to_memory('category_model')
+        ...
 
     def load_model_to_memory(self, model_name):
         model_version = pkg_resources.get_distribution('nkia').version
-
         os.makedirs(model_name) if model_name not in os.listdir() else ...
-        self.utils.get_model_files_by_version(model_name + '/', model_version)
+        utils.get_model_files_by_version(model_name + '/', model_version)
 
-        self.tokenizer = tfds.features.text.SubwordTextEncoder.load_from_file(
+        tokenizer = tfds.features.text.SubwordTextEncoder.load_from_file(
             './'+model_name+'/'+model_version+'/token')
 
         nb_classes = 29 if model_name == 'category_model' else 2
 
-        cnn = CNN(vocab_size=self.tokenizer.vocab_size, emb_dim=300, nb_filters=100,
+        cnn = CNN(vocab_size=tokenizer.vocab_size, emb_dim=300, nb_filters=100,
             ffn_units=256, nb_classes=nb_classes, dropout_rate=0.2)
 
         cnn.load_weights('./'+model_name+'/'+model_version+'/model_checkpoint/cp.ckpt').expect_partial()
@@ -46,25 +44,17 @@ class classifyProducts(object):
             str: Category name. e.g: 'Bebidas não alcoolicas'
 
         """     
-        model_version = pkg_resources.get_distribution('nkia').version
-
-        X = self.utils.get_cleaned_predictor([description], [product_name])
-        X = self.preprocessing_fn(X, './category_model'+'/'+model_version+'/token')
-
-        label_encoder = self.get_label_encoder('./category_model'+'/'+model_version+'/label_encoder.pkl')
+        X = self.preprocessing_fn(product_name, description, './category_model')
 
         product_category = model(np.array(X), training=False).numpy()[0]
-
         product_category_proba = product_category[product_category.argmax()]
 
         if product_category_proba < 0.6:
-            product_category = 'categoria desconhecida'
-        else:
-            product_category = label_encoder.inverse_transform([product_category.argmax()])[0]
+            return 'categoria desconhecida'
 
-        return product_category
+        return self.label_encoder.inverse_transform([product_category.argmax()])[0]
 
-    def inference_from_food_model(self, model, product_name):
+    def inference_from_food_model(self, model, product_name=[''], description=['']):
         """
         This method is responsible to infer if a product is a food or not. Pass just one product
         by time.
@@ -76,19 +66,23 @@ class classifyProducts(object):
             str: food or not food.
 
         """     
-        X = self.utils.get_description_and_name(product_name)
-        X = self.preprocessing_fn([X], './food_model/v1/token')
-
-        label_encoder = self.get_label_encoder('./food_model/v1/label_encoder.pkl')
+        X = self.preprocessing_fn(product_name, description, './food_model')
 
         product_type = model(np.array(X), training=False).numpy()
         product_type = 1 if product_type > 0.5 else 0
 
-        return label_encoder.inverse_transform([product_type])[0] 
+        return self.label_encoder.inverse_transform([product_type])[0] 
 
-    def preprocessing_fn(self, X, token_path):
-        self.tokenizer = tfds.features.text.SubwordTextEncoder.load_from_file(token_path)
-        tokenized_predictor = [self.tokenizer.encode(sentence) for sentence in  X] 
+    def preprocessing_fn(self, product_name, description, model_name):       
+        model_version = pkg_resources.get_distribution('nkia').version
+        tokenizer = tfds.features.text.SubwordTextEncoder.load_from_file(
+            './'+model_name+'/'+model_version+'/token')
+
+        X = utils.get_cleaned_predictor([description], [product_name])
+
+        tokenized_predictor = [tokenizer.encode(sentence) for sentence in X] 
+
+        self.label_encoder = self.get_label_encoder(model_name+'/'+model_version+'/label_encoder.pkl')
 
         return tokenized_predictor
 
@@ -98,4 +92,4 @@ class classifyProducts(object):
         pkl_encoder_file.close()
         return encoder
 
-classifyProducts()
\ No newline at end of file
+classifyProducts()
